## 0.2.1 (2023-01-10)

### Fix

- ipython constraint >=7.31.1

## 0.2.0 (2023-01-09)

### Feat

- config value cadquery_include_source
- directive aliases cadquery-svg and cadquery-vtk

### Fix

- vtk.js html template text-align

### Refactor

- remove unused code

## 0.1.0 (2023-01-05)

### Feat

- vtk.js and svg renderers from cq
